Struct UsbIoProtocol
Source #[repr(C)]
pub struct UsbIoProtocol {Show 13 fields
pub control_transfer: unsafe extern "efiapi" fn(this: *mut Self, request: *mut DeviceRequest, direction: DataDirection, timeout: u32, data: *mut c_void, data_length: usize, status: *mut UsbTransferStatus) -> Status,
pub bulk_transfer: unsafe extern "efiapi" fn(this: *mut Self, device_endpoint: u8, data: *mut c_void, data_length: *mut usize, timeout: usize, status: *mut UsbTransferStatus) -> Status,
pub async_interrupt_transfer: unsafe extern "efiapi" fn(this: *mut Self, device_endpoint: u8, is_new_transfer: Boolean, polling_interval: usize, data_length: usize, interrupt_callback: AsyncUsbTransferCallback, context: *mut c_void) -> Status,
pub sync_interrupt_transfer: unsafe extern "efiapi" fn(this: *mut Self, device_endpoint: u8, data: *mut c_void, data_length: *mut usize, timeout: usize, status: *mut UsbTransferStatus) -> Status,
pub isochronous_transfer: unsafe extern "efiapi" fn(this: *mut Self, device_endpoint: u8, data: *mut c_void, data_length: usize, status: *mut UsbTransferStatus) -> Status,
pub async_isochronous_transfer: unsafe extern "efiapi" fn(this: *mut Self, device_endpoint: u8, data: *mut c_void, data_length: usize, isochronous_callback: AsyncUsbTransferCallback, context: *mut c_void) -> Status,
pub get_device_descriptor: unsafe extern "efiapi" fn(this: *mut Self, device_descriptor: *mut DeviceDescriptor) -> Status,
pub get_config_descriptor: unsafe extern "efiapi" fn(this: *mut Self, config_descriptor: *mut ConfigDescriptor) -> Status,
pub get_interface_descriptor: unsafe extern "efiapi" fn(this: *mut Self, interface_descriptor: *mut InterfaceDescriptor) -> Status,
pub get_endpoint_descriptor: unsafe extern "efiapi" fn(this: *mut Self, endpoint_index: u8, endpoint_descriptor: *mut EndpointDescriptor) -> Status,
pub get_string_descriptor: unsafe extern "efiapi" fn(this: *mut Self, lang_id: u16, string_id: u8, string: *mut *mut Char16) -> Status,
pub get_supported_languages: unsafe extern "efiapi" fn(this: *mut Self, lang_id_table: *mut *mut u16, table_size: *mut u16) -> Status,
pub port_reset: unsafe extern "efiapi" fn(this: *mut Self) -> Status,
}
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.